==> pdfjs-vue3-ypp-1.0.0.tgz: package/lib/pdfjs-vue3-ypp.js <==
import './index.css';
import { defineComponent, useCssVars, ref, onMounted, nextTick, watch, openBlock, createElementBlock, createElementVNode } from "vue";
const _hoisted_1 = { class: "container" };
const _hoisted_2 = ["src"];
const fileUrl = "/pdfjs-4.8.69-dist/web/viewer.html?file=";
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "subPdf",
  props: {
    url: {
      type: String,
      default: ""
    },
    fileName: {
      type: String,
      defaul: ""
    },
    width: {
      type: String,
      default: "100%"
    },
    height: {
      type: String,
      default: "100%"
    },
    page: {
      type: Number,
      default: "1"
    }
  },
  setup(__props) {
    useCssVars((_ctx) => ({
      "598fe782": width.value,
      "82c3e22a": height.value
    }));
    const props = __props;
    const url = ref(props.url);
    const width = ref(props.width);
    const height = ref(props.height);
    const page = ref(props.page);
    const pdfUrl = ref("");
    const isRender = ref(false);
    onMounted(() => {
      pdfUrl.value = fileUrl + encodeURIComponent(url.value) + `&page=${page.value}`;
      nextTick(() => {
        isRender.value = true;
      });
    });
    watch(props, (newVal, old) => {
      if (isRender.value) {
        if (pdfUrl.value !== "" && newVal === old.fileName) {
          const pdfFrame = document.getElementById("myIframe").contentWindow;
          pdfFrame.PDFViewerApplication.pdfViewer.scrollPageIntoView({
            pageNumber: props.page
          });
        } else {
          pdfUrl.value = fileUrl + encodeURIComponent(props.url) + `&page=${props.page}`;
        }
      }
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1, [
        createElementVNode("iframe", {
          src: pdfUrl.value,
          id: "myIframe",
          width: "100%",
          height: "100%"
        }, null, 8, _hoisted_2)
      ]);
    };
  }
});
const _export_sfc = (sfc, props) => {
  const target = sfc.__vccOpts || sfc;
  for (const [key, val] of props) {
    target[key] = val;
  }
  return target;
};
const pdf = /* @__PURE__ */ _export_sfc(_sfc_main, [["__scopeId", "data-v-b1d7703f"]]);
pdf.install = function(Vue) {
  Vue.component(pdf.__name, pdf);
};
export {
  pdf as default
};

==> pdfjs-vue3-ypp-1.0.1.tgz: package/lib/pdfjs-vue3-ypp.js <==
import './index.css';
import { defineComponent, useCssVars, ref, onMounted, nextTick, watch, openBlock, createElementBlock, createElementVNode } from "vue";
const _hoisted_1 = { class: "container" };
const _hoisted_2 = ["src"];
const fileUrl = "/pdfjs-4.8.69-dist/web/viewer.html?file=";
const _sfc_main = /* @__PURE__ */ defineComponent({
  __name: "subPdf",
  props: {
    url: {
      type: String,
      default: ""
    },
    fileName: {
      type: String,
      defaul: ""
    },
    width: {
      type: String,
      default: "100%"
    },
    height: {
      type: String,
      default: "100%"
    },
    page: {
      type: Number,
      default: "1"
    }
  },
  setup(__props) {
    useCssVars((_ctx) => ({
      "4248702f": width.value,
      "2612c844": height.value
    }));
    const props = __props;
    const url = ref(props.url);
    const width = ref(props.width);
    const height = ref(props.height);
    const page = ref(props.page);
    const pdfUrl = ref("");
    const isRender = ref(false);
    onMounted(() => {
      pdfUrl.value = fileUrl + encodeURIComponent(url.value) + `&page=${page.value}`;
      nextTick(() => {
        isRender.value = true;
      });
    });
    watch(props, (newVal, old) => {
      if (isRender.value) {
        if (pdfUrl.value !== "" && newVal.fileName === old.fileName) {
          const pdfFrame = document.getElementById("myIframe").contentWindow;
          pdfFrame.PDFViewerApplication.pdfViewer.scrollPageIntoView({
            pageNumber: props.page
          });
        } else {
          pdfUrl.value = fileUrl + encodeURIComponent(props.url) + `&page=${props.page}`;
        }
      }
    });
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", _hoisted_1, [
        createElementVNode("iframe", {
          src: pdfUrl.value,
          id: "myIframe",
          width: "100%",
          height: "100%"
        }, null, 8, _hoisted_2)
      ]);
    };
  }
});
const _export_sfc = (sfc, props) => {
  const target = sfc.__vccOpts || sfc;
  for (const [key, val] of props) {
    target[key] = val;
  }
  return target;
};
const pdf = /* @__PURE__ */ _export_sfc(_sfc_main, [["__scopeId", "data-v-9af0c0bd"]]);
pdf.install = function(Vue) {
  Vue.component(pdf.__name, pdf);
};
export {
  pdf as default
};
